@@ -286,6 +286,8 @@ struct License<'a> {
     name: String,
     /// The SPDX short identifier for the license
     id: String,
+    /// True if this is the first license of its kind in the flat array
+    first_of_kind: bool,
     /// The full license text
     text: String,
     /// The path where the license text was sourced from
@@ -322,7 +324,7 @@ fn generate<'kl>(
 
     let diag_cfg = term::Config::default();
 
-    let licenses = {
+    let mut licenses = {
         let mut licenses = BTreeMap::new();
         for (krate_license, resolved) in nfos
             .iter()
@@ -369,6 +371,7 @@ fn generate<'kl>(
                                             text: text.clone(),
                                             source_path: Some(lf.path.clone()),
                                             used_by: Vec::new(),
+                                            first_of_kind: false,
                                         };
                                         Some(license)
                                     }
@@ -390,6 +393,7 @@ fn generate<'kl>(
                                 text: id.text().to_owned(),
                                 source_path: None,
                                 used_by: Vec::new(),
+                                first_of_kind: false,
                             });
                         }
                     }
@@ -439,7 +443,7 @@ fn generate<'kl>(
 
     let mut overview: Vec<LicenseSet> = Vec::with_capacity(256);
 
-    for (ndx, lic) in licenses.iter().enumerate() {
+    for (ndx, lic) in licenses.iter_mut().enumerate() {
         match overview.binary_search_by(|i| i.id.cmp(&lic.id)) {
             Ok(i) => {
                 let ov = &mut overview[i];
@@ -457,6 +461,7 @@ fn generate<'kl>(
 
                 ls.indices.push(ndx);
                 overview.insert(i, ls);
+                lic.first_of_kind = true;
             }
         }
     }
